@@ -4,13 +4,13 @@ from matplotlib.path import Path
 
 class BinaryRenderer:
 
-    def __init__(self, size, fill_value: bool = False):
+    def __init__(self, size, fill_value: bool = False) -> None:
         self.map = np.full(size, fill_value=fill_value, dtype=bool)
 
         self.xx, self.yy = np.meshgrid(range(size[1]), range(size[0]))
         self.xy = np.vstack((self.xx.flatten(), self.yy.flatten())).T
 
-    def circle(self, x, y, radius, value=True):
+    def circle(self, x, y, radius, value=True) -> None:
         x0 = max(int(x - radius), 0)
         y0 = max(int(y - radius), 0)
         x1 = min(int(x + radius) + 2, self.map.shape[1] - 1)
@@ -20,7 +20,9 @@ class BinaryRenderer:
         roi[sqr_dist <= radius**2] = value
         self.map[y0:y1, x0:x1] = roi
 
-    def polygon(self, points, value=True):
+    def polygon(self, points, value=True) -> None:
+        if len(points) == 0:
+            return
         x0 = max(int(points[:, 0].min()), 0)
         y0 = max(int(points[:, 1].min()), 0)
         x1 = min(int(points[:, 0].max()) + 2, self.map.shape[1] - 1)
