@@ -1,9 +1,11 @@
 #!/usr/bin/env python3
-from nicegui import ui
+import time
+
 import numpy as np
 import pylab as pl
-import time
-from rosys.pathplanning.binary_renderer import BinaryRenderer
+from nicegui import ui
+
+from .binary_renderer import BinaryRenderer
 
 renderer = BinaryRenderer((30, 40), fill_value=True)
 
