@@ -1,13 +1,14 @@
 #!/usr/bin/env python3
-from nicegui import ui
-import pylab as pl
-import numpy as np
 import time
-from rosys.world import Pose, Spline
+
+import numpy as np
+import pylab as pl
+from nicegui import ui
+from rosys.geometry import Pose, Spline
+from rosys.pathplanning import plot_tools as pt
 from rosys.pathplanning.grid import Grid
-from rosys.pathplanning.robot_renderer import RobotRenderer
 from rosys.pathplanning.obstacle_map import ObstacleMap
-import rosys.pathplanning.plot_tools as pt
+from rosys.pathplanning.robot_renderer import RobotRenderer
 
 grid = Grid((30, 40, 36), (0.45, -0.05, 4.0, 3.0))
 obstacles = [
