@@ -1,19 +1,20 @@
 import asyncio
 import logging
+import os
 import shlex
+import signal
 import subprocess
 import uuid
 from asyncio.subprocess import Process
 from concurrent.futures import ProcessPoolExecutor, ThreadPoolExecutor
 from contextlib import contextmanager
-from typing import Callable, Optional, Union
+from typing import Callable, Generator, Optional
 
-from .helpers import is_test
+import rosys
 
 process_pool = ProcessPoolExecutor()
 thread_pool = ThreadPoolExecutor(thread_name_prefix='run.py thread_pool')
-# NOTE is used in rosys.test.Runtime to advance time slower until computation is done
-running_cpu_bound_processes: list[int] = []
+running_cpu_bound_processes: list[int] = []  # NOTE is used in tests to advance time slower until computation is done
 running_sh_processes: list[Process] = []
 log = logging.getLogger('rosys.run')
 
@@ -42,7 +43,7 @@ async def cpu_bound(callback: Callable, *args: any):
 
 
 @contextmanager
-def cpu():
+def cpu() -> Generator[None, None, None]:
     id = str(uuid.uuid4())
     running_cpu_bound_processes.append(id)
     try:
@@ -51,15 +52,19 @@ def cpu():
         running_cpu_bound_processes.remove(id)
 
 
-async def sh(command: Union[list[str], str], timeout: Optional[float] = 1, shell=False) -> str:
+async def sh(command: list[str] | str, timeout: Optional[float] = 1, shell: bool = False) -> str:
     '''executes a shell command
-    command: a sequence of program arguments as subprocess.Popen requires or full string
-    shell: weather a sub shell should be launched (default is False, for speed, use True if you need file globbing or other features);
-    returns: stdout
+
+    Args:
+        command: a sequence of program arguments as subprocess.Popen requires or full string
+        shell: whether a subshell should be launched (default is `False`, for speed, use `True` if you need file globbing or other features)
+
+    Returns:
+        stdout
     '''
     def popen() -> str:
         if shell:  # convert to string
-            cmd = (' '.join(command)) if isinstance(command, list) else command
+            cmd = ' '.join(command) if isinstance(command, list) else command
         else:  # convert to list
             cmd = shlex.split(command) if isinstance(command, str) else command
         if timeout is not None:
@@ -68,23 +73,33 @@ async def sh(command: Union[list[str], str], timeout: Optional[float] = 1, shell
             else:
                 cmd = ['timeout', str(timeout)] + cmd
         #log.info(f'running sh: "{cmd}"')
-        with subprocess.Popen(
+        proc = subprocess.Popen(
             cmd,
             stdout=asyncio.subprocess.PIPE,
             stderr=asyncio.subprocess.STDOUT,
+            preexec_fn=os.setsid,  # set process group id to ensure child processes are killed when parent is killed
             shell=shell,
-        ) as proc:
-            stdout, *_ = proc.communicate()
-            return stdout.decode('utf-8')
+        )
+        running_sh_processes.append(proc)
+        stdout, *_ = proc.communicate()
+        try:
+            os.killpg(os.getpgid(proc.pid), signal.SIGTERM)
+        except ProcessLookupError:
+            pass
+        running_sh_processes.remove(proc)
+        return stdout.decode('utf-8')
     return await io_bound(popen)
 
 
 def tear_down() -> None:
+    # stopping process as described in https://www.cloudcity.io/blog/2019/02/27/things-i-wish-they-told-me-about-multiprocessing-in-python/
     log.info('teardown thread_pool')
     thread_pool.shutdown(wait=False, cancel_futures=True)
-    [p.kill() for p in running_sh_processes]
-    if not is_test:
+    [p.join(2) for p in running_sh_processes]
+    [p.terminate() for p in running_sh_processes if p.is_alive()]
+    running_sh_processes.clear()
+    if not rosys.is_test:
         log.info('teardown process_pool')
-        [p.kill() for p in process_pool._processes.values()]
+        [os.killpg(os.getpgid(p.pid), signal.SIGTERM) for p in process_pool._processes.values()]
         process_pool.shutdown(wait=True, cancel_futures=True)
     log.info('teardown complete')
